/*spectra.h      declarations for spectrum manipulation routines*/

struct spec2d_list {
    int x;
    int y;
};

void inc1d P((int, int));
void inc2d P((int, int, int));
void inc2d_list P((int, struct spec2d_list *, int));
void inc2d_col P((int, int, int *));
void inc2d_tartan P((int, int *));
void incv1d P((int, int, int));
void incv2d P((int, int, int, int));
int win2d P((int, int, int));
void set1d P((int, int, int));
void set2d P((int, int, int, int));
int val1d P((int, int));
int val2d P((int, int, int));
void dinc1d P((int, double));
void dinc2d P((int, double, double));
void dincv1d P((int, double, double));
void dincv2d P((int, double, double, double));
int dwin2d P((int, double, double));
void dset1d P((int, double, double));
void dset2d P((int, double, double, double));
int dval1d P((int, double));
int dval2d P((int, double, double));
